@@ -3,7 +3,7 @@ package Params::ValidationCompiler;
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use Params::ValidationCompiler::Compiler;
 
@@ -15,7 +15,10 @@ sub validation_for {
     return Params::ValidationCompiler::Compiler->new(@_)->subref;
 }
 
+## no critic (TestingAndDebugging::ProhibitNoWarnings)
+no warnings 'once';
 *compile = \&validation_for;
+## use critic
 
 sub source_for {
     return Params::ValidationCompiler::Compiler->new(@_)->source_for;
@@ -37,7 +40,7 @@ Params::ValidationCompiler - Build an optimized subroutine parameter validator o
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -45,7 +48,7 @@ version 0.09
     use Params::ValidationCompiler qw( validation_for );
 
     {
-        my $check = validation_for(
+        my $validator = validation_for(
             params => {
                 foo => { type => Int },
                 bar => {
@@ -60,7 +63,7 @@ version 0.09
         );
 
         sub do_something {
-            my %args = $check->(@_);
+            my %args = $validator->(@_);
         }
     }
 
